pub struct CrossDomainMapper { /* private fields */ }Expand description
Translates ternary patterns between different domains.
Domains are identified by string names. Each domain has a mapping that interprets ternary values in its own context.
Implementations
Sourceimpl CrossDomainMapper
impl CrossDomainMapper
pub fn new() -> Self
Sourcepub fn register_domain(
&mut self,
name: &str,
negative_label: &str,
zero_label: &str,
positive_label: &str,
)
pub fn register_domain( &mut self, name: &str, negative_label: &str, zero_label: &str, positive_label: &str, )
Register a domain with its ternary value interpretations.
Sourcepub fn translate(
&self,
pattern: &Pattern,
from_domain: &str,
to_domain: &str,
) -> Option<Vec<String>>
pub fn translate( &self, pattern: &Pattern, from_domain: &str, to_domain: &str, ) -> Option<Vec<String>>
Translate a pattern from one domain’s interpretation to another’s. The ternary values stay the same; only the labels change.
Sourcepub fn label_for(&self, domain: &str, value: Ternary) -> Option<&str>
pub fn label_for(&self, domain: &str, value: Ternary) -> Option<&str>
Get the label for a value in a specific domain.
Sourcepub fn domain_names(&self) -> Vec<&str>
pub fn domain_names(&self) -> Vec<&str>
List registered domain names.