PatternGenerator

Struct PatternGenerator 

pub struct PatternGenerator {
    pub seed: usize,
}
Generates novel ternary patterns using deterministic seeds.

Fields

seed: usize

Base seed for generation.

Implementations

Source

impl PatternGenerator

pub fn new(seed: usize) -> Self

pub fn generate(&self, length: usize) -> Pattern

Generate a pattern of given length using the seed.

pub fn generate_symmetric(&self, half_length: usize) -> Pattern

Generate a symmetric pattern.

pub fn generate_weighted( &self, length: usize, neg_weight: f64, zero_weight: f64, pos_weight: f64, ) -> Pattern

Generate a pattern with a specific ratio of each value type.