pub struct StyleTransfer { /* private fields */ }Expand description
Applies patterns from one domain onto another by mapping ternary values.
Implementations
Sourceimpl StyleTransfer
impl StyleTransfer
pub fn new() -> Self
Sourcepub fn add_rule(&mut self, source: &str, target: Ternary)
pub fn add_rule(&mut self, source: &str, target: Ternary)
Add a style rule: source value → target value.
Sourcepub fn apply(&self, pattern: &Pattern) -> Pattern
pub fn apply(&self, pattern: &Pattern) -> Pattern
Apply style rules to a pattern, replacing values that match rules.